@@ -9,9 +9,9 @@ def print_info() -> None:
     Print package info to stdout.
     """
     print(
-        "Type annotations for boto3 9.6.0\n"
-        "Version:         9.6.0.post2\n"
-        "Builder version: 7.10.0\n"
+        "Type annotations for boto3 11.0.0\n"
+        "Version:         11.0.0\n"
+        "Builder version: 7.12.5\n"
         "Docs:            https://pypi.org/project/types-aioboto3/\n"
         "Changelog:       https://github.com/youtype/mypy_boto3_builder/releases"
     )
@@ -21,7 +21,7 @@ def print_version() -> None:
     """
     Print package version to stdout.
     """
-    print("9.6.0.post2")
+    print("11.0.0")
 
 
 def main() -> None:
